@@ -1,12 +1,11 @@
-from __future__ import absolute_import
-
 from collections import defaultdict
 from contextlib import contextmanager
+from itertools import chain
+import urllib
 
 import click
 import flask
 import flask.cli
-from six.moves import urllib
 
 from keg import current_app
 from keg.extensions import gettext as _
@@ -38,29 +37,46 @@ class KegAppGroup(flask.cli.AppGroup):
     def _load_plugin_commands(self):
         if self._loaded_plugin_commands:
             return
+        entry_point_iterables = []
+
+        # older Flask
         try:
             import pkg_resources
+            entry_point_iterables.extend([
+                pkg_resources.iter_entry_points('flask.commands'),
+                pkg_resources.iter_entry_points('keg.commands'),
+            ])
         except ImportError:
-            self._loaded_plugin_commands = True
             return
 
-        for ep in pkg_resources.iter_entry_points('flask.commands'):
-            self.add_command(ep.load(), ep.name)
-        for ep in pkg_resources.iter_entry_points('keg.commands'):
+        # newer Flask
+        try:
+            # uses importlib, but python has some API variations. Let flask handle that.
+            from flask.cli import metadata
+            entry_point_iterables.extend([
+                metadata.entry_points(group="flask.commands"),
+                metadata.entry_points(group="keg.commands"),
+            ])
+        except ImportError:
+            pass
+
+        for ep in chain.from_iterable(entry_point_iterables):
             self.add_command(ep.load(), ep.name)
         self._loaded_plugin_commands = True
 
-    def list_commands(self, ctx):
+    def _load_app(self, ctx):
         self._load_plugin_commands()
 
         info = ctx.ensure_object(flask.cli.ScriptInfo)
         info.load_app()
+
+    def list_commands(self, ctx):
+        self._load_app(ctx)
         rv = set(click.Group.list_commands(self, ctx))
         return sorted(rv)
 
     def get_command(self, ctx, name):
-        info = ctx.ensure_object(flask.cli.ScriptInfo)
-        info.load_app()
+        self._load_app(ctx)
         return click.Group.get_command(self, ctx, name)
 
     def main(self, *args, **kwargs):
@@ -188,8 +204,14 @@ def database_group(ctx):
 @click.command('init', short_help=_('Create all db objects, send related events.'))
 @click.option('--clear-first', default=False, is_flag=True,
               help=_('Clear DB of all data and drop all objects before init.'))
+@click.option('--yes', default=False, is_flag=True, help="Force confirmation")
 @flask.cli.with_appcontext
-def database_init(clear_first):
+def database_init(clear_first, yes):
+    prompt = clear_first and not yes
+    if prompt and not click.confirm(_('Are you sure? You will delete all the data!')):
+        click.echo('Database untouched')
+        return
+
     if clear_first:
         current_app.db_manager.db_init_with_clear()
         click.echo(_('Database cleared and initialized'))
@@ -199,10 +221,14 @@ def database_init(clear_first):
 
 
 @click.command('clear', short_help=_('Clear DB of all data and drop all objects.'))
+@click.option('--yes', default=False, is_flag=True, help="Force confirmation")
 @flask.cli.with_appcontext
-def database_clear():
-    current_app.db_manager.db_clear()
-    click.echo(_('Database cleared'))
+def database_clear(yes):
+    if yes or click.confirm(_('Are you sure? You will delete all the data!')):
+        current_app.db_manager.db_clear()
+        click.echo(_('Database cleared'))
+    else:
+        click.echo(_('Database untouched'))
 
 
 class CLILoader(object):
