@@ -1,8 +1,6 @@
-from __future__ import absolute_import
-
 import os
+from unittest import mock
 
-import mock
 import pytest
 
 from keg.cli import dotenv, get_load_dotenv
@@ -40,9 +38,12 @@ class TestCLI(CLIBase):
     @need_dotenv
     def test_dotenv(self):
         test_dir = os.path.dirname(__file__)
+        # ensure flask looks in the expected working directory
+        working_dir = os.path.abspath(os.path.join(test_dir, '..', '..'))
+        os.chdir(working_dir)
 
         # Place dotenv file in search path of python-dotenv
-        flaskenv = os.path.abspath(os.path.join(test_dir, '..', '..', '.flaskenv'))
+        flaskenv = os.path.join(working_dir, '.flaskenv')
         try:
             with open(flaskenv, 'w') as f:
                 f.write('FOO=bar')
@@ -57,9 +58,12 @@ class TestCLI(CLIBase):
     @mock.patch.dict(os.environ, {'FLASK_SKIP_DOTENV': '1'})
     def test_disable_dotenv_from_env(self):
         test_dir = os.path.dirname(__file__)
+        # ensure flask looks in the expected working directory
+        working_dir = os.path.abspath(os.path.join(test_dir, '..', '..'))
+        os.chdir(working_dir)
 
         # Place dotenv file in search path of python-dotenv
-        flaskenv = os.path.abspath(os.path.join(test_dir, '..', '..', '.flaskenv'))
+        flaskenv = os.path.join(working_dir, '.flaskenv')
         try:
             with open(flaskenv, 'w') as f:
                 f.write('FOO=bar')
@@ -167,12 +171,12 @@ class TestDatabaseCommands(CLIBase):
 
     @mock.patch('keg.db.DatabaseManager.db_init_with_clear')
     def test_init_with_clear(self, m_db_init_wc):
-        result = self.invoke('init', '--clear-first')
+        result = self.invoke('init', '--clear-first', '--yes')
         assert 'Database cleared and initialized' in result.output
         m_db_init_wc.assert_called_once_with()
 
     @mock.patch('keg.db.DatabaseManager.db_clear')
     def test_clear(self, m_db_clear):
-        result = self.invoke('clear')
+        result = self.invoke('clear', '--yes')
         assert 'Database cleared' in result.output
         m_db_clear.assert_called_once_with()
