@@ -1,13 +1,16 @@
-from __future__ import absolute_import
-
 import inspect
 import sys
+from warnings import warn
 
 from blazeutils.strings import case_cw2us, case_cw2dash
 import flask
-from flask import request
-from flask.views import MethodView, MethodViewType, http_method_funcs
-import six
+from flask import current_app, request
+from flask.views import MethodView, http_method_funcs
+try:
+    from flask.views import MethodViewType
+except ImportError:
+    MethodViewType = None
+from jinja2 import TemplateNotFound
 from werkzeug.datastructures import MultiDict
 
 from keg.extensions import lazy_gettext as _
@@ -48,7 +51,7 @@ def _werkzeug_multi_dict_conv(md):
         if only one value or a list if multiple values
     '''
     retval = {}
-    for key, value in six.iteritems(md.to_dict(flat=False)):
+    for key, value in md.to_dict(flat=False).items():
         if len(value) == 1:
             retval[key] = value[0]
         else:
@@ -58,7 +61,7 @@ def _werkzeug_multi_dict_conv(md):
 
 def _call_with_expected_args(view, calling_args, method, method_is_bound=True):
     """ handle argument conversion to what the method accepts """
-    if isinstance(method, six.string_types):
+    if isinstance(method, str):
         if not hasattr(view, method):
             return
         method = getattr(view, method)
@@ -82,7 +85,7 @@ def _call_with_expected_args(view, calling_args, method, method_is_bound=True):
     return method(*args, **kwargs)
 
 
-class _ViewMeta(MethodViewType):
+class _OldViewMeta(MethodViewType or object):
     def __init__(cls, name, bases, d):
         MethodViewType.__init__(cls, name, bases, d)
 
@@ -94,6 +97,9 @@ class _ViewMeta(MethodViewType):
             cls.assign_blueprint(cls.blueprint)
 
 
+_ViewMeta = _OldViewMeta if MethodViewType is not None else type
+
+
 class BaseView(MethodView, metaclass=_ViewMeta):
     """
     Base class for all Keg views to inherit from. `BaseView` automatically calculates and installs
@@ -111,6 +117,15 @@ class BaseView(MethodView, metaclass=_ViewMeta):
     # names of qs arguments that should be merged w/ URL arguments and passed to view methods
     expected_qs_args = []
 
+    def __init_subclass__(cls, **kwargs):
+        """Flask before 2.2.0 used a metaclass to perform view setup, but this
+        changed to using `init_subclass`. If the old way is enabled, no need to
+        do anything but call the super here."""
+        super().__init_subclass__(**kwargs)
+
+        if MethodViewType is None and cls.blueprint is not None:
+            cls.assign_blueprint(cls.blueprint)
+
     def __init__(self, responding_method=None):
         self.responding_method = responding_method
 
@@ -167,7 +182,7 @@ class BaseView(MethodView, metaclass=_ViewMeta):
         # start with query string arguments that are expected
         args = MultiDict()
         if self.expected_qs_args:
-            for k in six.iterkeys(request.args):
+            for k in request.args.keys():
                 if k in self.expected_qs_args:
                     args.setlist(k, request.args.getlist(k))
 
@@ -175,7 +190,7 @@ class BaseView(MethodView, metaclass=_ViewMeta):
         # arguments get precedence and we don't want to just .update()
         # because that would allow arbitrary get arguments to affect the
         # values of the URL arguments
-        for k, v in six.iteritems(urlargs):
+        for k, v in urlargs.items():
             args[k] = v
 
         return _werkzeug_multi_dict_conv(args)
@@ -200,16 +215,44 @@ class BaseView(MethodView, metaclass=_ViewMeta):
         for key in self.auto_assign:
             self.assign(key, getattr(self, key))
 
-    def calc_class_fname(self):
-        return case_cw2us(self.__class__.__name__)
+    def calc_class_fname(self, use_us=False):
+        if use_us:
+            return case_cw2us(self.__class__.__name__)
+        return case_cw2dash(self.__class__.__name__)
 
-    def calc_template_name(self):
+    def calc_template_name(self, use_us=False):
         if self.template_name is not None:
             return self.template_name
-        template_path = '{}.html'.format(self.calc_class_fname())
+        template_path = '{}.html'.format(self.calc_class_fname(use_us=use_us))
         blueprint_name = request.blueprint
         if blueprint_name:
             template_path = '{}/{}'.format(blueprint_name, template_path)
+
+        # This block and `use_us` usage can be removed when we drop
+        # template names generated with underscores.
+        jinja_env = current_app.jinja_env
+        try:
+            jinja_env.get_template(template_path)
+        except TemplateNotFound:
+            raise_original_exception = False
+            if not use_us:
+                # Fall back to underscore-named templates for now, but warn if
+                # that succeeds
+                try:
+                    template_path = self.calc_template_name(use_us=True)
+                    warn(
+                        'Templates named by underscore-notated class names are '
+                        'deprecated and will not be supported. Rename the template '
+                        'files using dashes.',
+                        DeprecationWarning,
+                        stacklevel=2
+                    )
+                except TemplateNotFound:
+                    # Neither template exists. Raise the exception from the dashed name
+                    raise_original_exception = True
+            if use_us or raise_original_exception:
+                raise
+
         return template_path
 
     def assign(self, key, value):
@@ -272,16 +315,16 @@ class BaseView(MethodView, metaclass=_ViewMeta):
             str_endpoint = str(endpoint)
             view_func = cls.as_view(str_endpoint)
 
-            absolute_found = False
             for rule, options in rules:
-                if rule.startswith('/'):
-                    absolute_found = True
+                if rule and rule.startswith('/'):
                     class_url = rule
+                elif not rule:
+                    rule = class_url
                 else:
                     rule = '{}/{}'.format(class_url, rule)
                 cls.blueprint.add_url_rule(rule, endpoint=endpoint, view_func=view_func, **options)
 
-            if not absolute_found:
+            if not rules:
                 cls.blueprint.add_url_rule(class_url, endpoint=endpoint, view_func=view_func)
 
         for rule, options in cls.url_rules:
